@@ -36,12 +36,17 @@ __all__ = (
     "EventCategoryGroupTypeDef",
     "EventSubscriptionTypeDef",
     "EventTypeDef",
+    "IBMDb2SettingsTypeDef",
     "KafkaSettingsTypeDef",
     "KinesisSettingsTypeDef",
+    "MicrosoftSQLServerSettingsTypeDef",
     "MongoDbSettingsTypeDef",
+    "MySQLSettingsTypeDef",
     "NeptuneSettingsTypeDef",
+    "OracleSettingsTypeDef",
     "OrderableReplicationInstanceTypeDef",
     "PendingMaintenanceActionTypeDef",
+    "PostgreSQLSettingsTypeDef",
     "RedshiftSettingsTypeDef",
     "RefreshSchemasStatusTypeDef",
     "ReplicationInstanceTaskLogTypeDef",
@@ -49,16 +54,21 @@ __all__ = (
     "ReplicationPendingModifiedValuesTypeDef",
     "ReplicationSubnetGroupTypeDef",
     "ReplicationTaskAssessmentResultTypeDef",
+    "ReplicationTaskAssessmentRunProgressTypeDef",
+    "ReplicationTaskAssessmentRunTypeDef",
+    "ReplicationTaskIndividualAssessmentTypeDef",
     "ReplicationTaskStatsTypeDef",
     "ReplicationTaskTypeDef",
     "ResourcePendingMaintenanceActionsTypeDef",
     "S3SettingsTypeDef",
     "SubnetTypeDef",
     "SupportedEndpointTypeTypeDef",
+    "SybaseSettingsTypeDef",
     "TableStatisticsTypeDef",
     "TagTypeDef",
     "VpcSecurityGroupMembershipTypeDef",
     "ApplyPendingMaintenanceActionResponseTypeDef",
+    "CancelReplicationTaskAssessmentRunResponseTypeDef",
     "CreateEndpointResponseTypeDef",
     "CreateEventSubscriptionResponseTypeDef",
     "CreateReplicationInstanceResponseTypeDef",
@@ -69,8 +79,10 @@ __all__ = (
     "DeleteEndpointResponseTypeDef",
     "DeleteEventSubscriptionResponseTypeDef",
     "DeleteReplicationInstanceResponseTypeDef",
+    "DeleteReplicationTaskAssessmentRunResponseTypeDef",
     "DeleteReplicationTaskResponseTypeDef",
     "DescribeAccountAttributesResponseTypeDef",
+    "DescribeApplicableIndividualAssessmentsResponseTypeDef",
     "DescribeCertificatesResponseTypeDef",
     "DescribeConnectionsResponseTypeDef",
     "DescribeEndpointTypesResponseTypeDef",
@@ -85,6 +97,8 @@ __all__ = (
     "DescribeReplicationInstancesResponseTypeDef",
     "DescribeReplicationSubnetGroupsResponseTypeDef",
     "DescribeReplicationTaskAssessmentResultsResponseTypeDef",
+    "DescribeReplicationTaskAssessmentRunsResponseTypeDef",
+    "DescribeReplicationTaskIndividualAssessmentsResponseTypeDef",
     "DescribeReplicationTasksResponseTypeDef",
     "DescribeSchemasResponseTypeDef",
     "DescribeTableStatisticsResponseTypeDef",
@@ -101,6 +115,7 @@ __all__ = (
     "RefreshSchemasResponseTypeDef",
     "ReloadTablesResponseTypeDef",
     "StartReplicationTaskAssessmentResponseTypeDef",
+    "StartReplicationTaskAssessmentRunResponseTypeDef",
     "StartReplicationTaskResponseTypeDef",
     "StopReplicationTaskResponseTypeDef",
     "TableToReloadTypeDef",
@@ -195,6 +210,12 @@ EndpointTypeDef = TypedDict(
         "ElasticsearchSettings": "ElasticsearchSettingsTypeDef",
         "NeptuneSettings": "NeptuneSettingsTypeDef",
         "RedshiftSettings": "RedshiftSettingsTypeDef",
+        "PostgreSQLSettings": "PostgreSQLSettingsTypeDef",
+        "MySQLSettings": "MySQLSettingsTypeDef",
+        "OracleSettings": "OracleSettingsTypeDef",
+        "SybaseSettings": "SybaseSettingsTypeDef",
+        "MicrosoftSQLServerSettings": "MicrosoftSQLServerSettingsTypeDef",
+        "IBMDb2Settings": "IBMDb2SettingsTypeDef",
     },
     total=False,
 )
@@ -231,7 +252,26 @@ EventTypeDef = TypedDict(
     total=False,
 )
 
-KafkaSettingsTypeDef = TypedDict("KafkaSettingsTypeDef", {"Broker": str, "Topic": str}, total=False)
+IBMDb2SettingsTypeDef = TypedDict(
+    "IBMDb2SettingsTypeDef",
+    {"DatabaseName": str, "Password": str, "Port": int, "ServerName": str, "Username": str},
+    total=False,
+)
+
+KafkaSettingsTypeDef = TypedDict(
+    "KafkaSettingsTypeDef",
+    {
+        "Broker": str,
+        "Topic": str,
+        "MessageFormat": Literal["json", "json-unformatted"],
+        "IncludeTransactionDetails": bool,
+        "IncludePartitionValue": bool,
+        "PartitionIncludeSchemaTable": bool,
+        "IncludeTableAlterOperations": bool,
+        "IncludeControlDetails": bool,
+    },
+    total=False,
+)
 
 KinesisSettingsTypeDef = TypedDict(
     "KinesisSettingsTypeDef",
@@ -248,6 +288,12 @@ KinesisSettingsTypeDef = TypedDict(
     total=False,
 )
 
+MicrosoftSQLServerSettingsTypeDef = TypedDict(
+    "MicrosoftSQLServerSettingsTypeDef",
+    {"Port": int, "DatabaseName": str, "Password": str, "ServerName": str, "Username": str},
+    total=False,
+)
+
 MongoDbSettingsTypeDef = TypedDict(
     "MongoDbSettingsTypeDef",
     {
@@ -267,6 +313,12 @@ MongoDbSettingsTypeDef = TypedDict(
     total=False,
 )
 
+MySQLSettingsTypeDef = TypedDict(
+    "MySQLSettingsTypeDef",
+    {"DatabaseName": str, "Password": str, "Port": int, "ServerName": str, "Username": str},
+    total=False,
+)
+
 _RequiredNeptuneSettingsTypeDef = TypedDict(
     "_RequiredNeptuneSettingsTypeDef", {"S3BucketName": str, "S3BucketFolder": str}
 )
@@ -287,6 +339,23 @@ class NeptuneSettingsTypeDef(_RequiredNeptuneSettingsTypeDef, _OptionalNeptuneSe
     pass
 
 
+OracleSettingsTypeDef = TypedDict(
+    "OracleSettingsTypeDef",
+    {
+        "AsmPassword": str,
+        "AsmServer": str,
+        "AsmUser": str,
+        "DatabaseName": str,
+        "Password": str,
+        "Port": int,
+        "SecurityDbEncryption": str,
+        "SecurityDbEncryptionName": str,
+        "ServerName": str,
+        "Username": str,
+    },
+    total=False,
+)
+
 OrderableReplicationInstanceTypeDef = TypedDict(
     "OrderableReplicationInstanceTypeDef",
     {
@@ -316,6 +385,12 @@ PendingMaintenanceActionTypeDef = TypedDict(
     total=False,
 )
 
+PostgreSQLSettingsTypeDef = TypedDict(
+    "PostgreSQLSettingsTypeDef",
+    {"DatabaseName": str, "Password": str, "Port": int, "ServerName": str, "Username": str},
+    total=False,
+)
+
 RedshiftSettingsTypeDef = TypedDict(
     "RedshiftSettingsTypeDef",
     {
@@ -433,6 +508,43 @@ ReplicationTaskAssessmentResultTypeDef = TypedDict(
     total=False,
 )
 
+ReplicationTaskAssessmentRunProgressTypeDef = TypedDict(
+    "ReplicationTaskAssessmentRunProgressTypeDef",
+    {"IndividualAssessmentCount": int, "IndividualAssessmentCompletedCount": int},
+    total=False,
+)
+
+ReplicationTaskAssessmentRunTypeDef = TypedDict(
+    "ReplicationTaskAssessmentRunTypeDef",
+    {
+        "ReplicationTaskAssessmentRunArn": str,
+        "ReplicationTaskArn": str,
+        "Status": str,
+        "ReplicationTaskAssessmentRunCreationDate": datetime,
+        "AssessmentProgress": "ReplicationTaskAssessmentRunProgressTypeDef",
+        "LastFailureMessage": str,
+        "ServiceAccessRoleArn": str,
+        "ResultLocationBucket": str,
+        "ResultLocationFolder": str,
+        "ResultEncryptionMode": str,
+        "ResultKmsKeyArn": str,
+        "AssessmentRunName": str,
+    },
+    total=False,
+)
+
+ReplicationTaskIndividualAssessmentTypeDef = TypedDict(
+    "ReplicationTaskIndividualAssessmentTypeDef",
+    {
+        "ReplicationTaskIndividualAssessmentArn": str,
+        "ReplicationTaskAssessmentRunArn": str,
+        "IndividualAssessmentName": str,
+        "Status": str,
+        "ReplicationTaskIndividualAssessmentStartDate": datetime,
+    },
+    total=False,
+)
+
 ReplicationTaskStatsTypeDef = TypedDict(
     "ReplicationTaskStatsTypeDef",
     {
@@ -535,6 +647,12 @@ SupportedEndpointTypeTypeDef = TypedDict(
     total=False,
 )
 
+SybaseSettingsTypeDef = TypedDict(
+    "SybaseSettingsTypeDef",
+    {"DatabaseName": str, "Password": str, "Port": int, "ServerName": str, "Username": str},
+    total=False,
+)
+
 TableStatisticsTypeDef = TypedDict(
     "TableStatisticsTypeDef",
     {
@@ -573,6 +691,12 @@ ApplyPendingMaintenanceActionResponseTypeDef = TypedDict(
     total=False,
 )
 
+CancelReplicationTaskAssessmentRunResponseTypeDef = TypedDict(
+    "CancelReplicationTaskAssessmentRunResponseTypeDef",
+    {"ReplicationTaskAssessmentRun": "ReplicationTaskAssessmentRunTypeDef"},
+    total=False,
+)
+
 CreateEndpointResponseTypeDef = TypedDict(
     "CreateEndpointResponseTypeDef", {"Endpoint": "EndpointTypeDef"}, total=False
 )
@@ -625,6 +749,12 @@ DeleteReplicationInstanceResponseTypeDef = TypedDict(
     total=False,
 )
 
+DeleteReplicationTaskAssessmentRunResponseTypeDef = TypedDict(
+    "DeleteReplicationTaskAssessmentRunResponseTypeDef",
+    {"ReplicationTaskAssessmentRun": "ReplicationTaskAssessmentRunTypeDef"},
+    total=False,
+)
+
 DeleteReplicationTaskResponseTypeDef = TypedDict(
     "DeleteReplicationTaskResponseTypeDef",
     {"ReplicationTask": "ReplicationTaskTypeDef"},
@@ -637,6 +767,12 @@ DescribeAccountAttributesResponseTypeDef = TypedDict(
     total=False,
 )
 
+DescribeApplicableIndividualAssessmentsResponseTypeDef = TypedDict(
+    "DescribeApplicableIndividualAssessmentsResponseTypeDef",
+    {"IndividualAssessmentNames": List[str], "Marker": str},
+    total=False,
+)
+
 DescribeCertificatesResponseTypeDef = TypedDict(
     "DescribeCertificatesResponseTypeDef",
     {"Marker": str, "Certificates": List["CertificateTypeDef"]},
@@ -727,6 +863,21 @@ DescribeReplicationTaskAssessmentResultsResponseTypeDef = TypedDict(
     total=False,
 )
 
+DescribeReplicationTaskAssessmentRunsResponseTypeDef = TypedDict(
+    "DescribeReplicationTaskAssessmentRunsResponseTypeDef",
+    {"Marker": str, "ReplicationTaskAssessmentRuns": List["ReplicationTaskAssessmentRunTypeDef"]},
+    total=False,
+)
+
+DescribeReplicationTaskIndividualAssessmentsResponseTypeDef = TypedDict(
+    "DescribeReplicationTaskIndividualAssessmentsResponseTypeDef",
+    {
+        "Marker": str,
+        "ReplicationTaskIndividualAssessments": List["ReplicationTaskIndividualAssessmentTypeDef"],
+    },
+    total=False,
+)
+
 DescribeReplicationTasksResponseTypeDef = TypedDict(
     "DescribeReplicationTasksResponseTypeDef",
     {"Marker": str, "ReplicationTasks": List["ReplicationTaskTypeDef"]},
@@ -807,6 +958,12 @@ StartReplicationTaskAssessmentResponseTypeDef = TypedDict(
     total=False,
 )
 
+StartReplicationTaskAssessmentRunResponseTypeDef = TypedDict(
+    "StartReplicationTaskAssessmentRunResponseTypeDef",
+    {"ReplicationTaskAssessmentRun": "ReplicationTaskAssessmentRunTypeDef"},
+    total=False,
+)
+
 StartReplicationTaskResponseTypeDef = TypedDict(
     "StartReplicationTaskResponseTypeDef",
     {"ReplicationTask": "ReplicationTaskTypeDef"},
@@ -817,9 +974,7 @@ StopReplicationTaskResponseTypeDef = TypedDict(
     "StopReplicationTaskResponseTypeDef", {"ReplicationTask": "ReplicationTaskTypeDef"}, total=False
 )
 
-TableToReloadTypeDef = TypedDict(
-    "TableToReloadTypeDef", {"SchemaName": str, "TableName": str}, total=False
-)
+TableToReloadTypeDef = TypedDict("TableToReloadTypeDef", {"SchemaName": str, "TableName": str})
 
 TestConnectionResponseTypeDef = TypedDict(
     "TestConnectionResponseTypeDef", {"Connection": "ConnectionTypeDef"}, total=False
